@@ -23,7 +23,7 @@ A new Net::ManageSieve object must be created with the I<new> method. Once
 this has been done, all ManageSieve commands are accessed through
 this object.
 
-I<Note>: ManageSieve allows to manipulate scripts on a host running a
+I<Note>: ManageSieve allows one to manipulate scripts on a host running a
 ManageSieve service, this module does not perform, validate or something
 like that Sieve scipts themselves.
 
@@ -92,7 +92,7 @@ this subroutine is called with the arguments:
 
 The return value controls, whether or not the error message will be
 assigned to C<$@>. Private functions may just signal that an error
-occured, but keep C<$@> unchanged. In this case C<$@> remains unchanged,
+occurred, but keep C<$@> unchanged. In this case C<$@> remains unchanged,
 if code_ref returns true.
 
 I<Note>: Even if the code ref returns false, C<$@> might bi clobberred
@@ -115,7 +115,7 @@ use Carp;
 use IO::Socket;
 use Encode;
 
-$VERSION = "0.10";
+$VERSION = "0.13";
 
 @ISA = qw();
 
@@ -308,7 +308,7 @@ sub close {
 =item starttls ( %SSL_opts )
 
 Initiates a TLS session, may be used only before any
-authentification.
+authentication.
 
 The C<SSL_opts> is a HASH containing any options you can
 pass to L<< IO::Socket::SSL->new() >>. No one is passed by default.
@@ -405,7 +405,7 @@ sub peer_certificate {
 Authentificates as C<USER>.
 
 If the module L<Authen::SASL> is available, this module is tried first. In
-this case, the C<USER> paramter may be a C<Authen::SASL> object, that
+this case, the C<USER> parameter may be a C<Authen::SASL> object, that
 is not furtherly modified. If C<USER> is no C<Authen::SASL> object, 
 C<USER> is passed as C<user>, C<PASSWORD> as C<pass> and C<AUTHNAME>
 as C<authname> to C<< Authen::SASL->new() >>. If C<AUTHNAME> is
@@ -566,7 +566,7 @@ sub host {
 
 =item capabilities ([reget])
 
-Returns the capabilites as HASH ref, e.g.:
+Returns the capabilities as HASH ref, e.g.:
 
 	{
 	  'starttls' => 1,
@@ -1034,7 +1034,7 @@ sub _token {
 		$l =~ s/\A[[:blank:]]+//;
 	}
 
-	if($l =~ /\A{(\d+)\+?}\r*\Z/) {	# The next $1 octets are the token
+	if($l =~ /\A\{(\d+)\+?\}\r*\Z/) {	# The next $1 octets are the token
 		my $cnt = $1;
 		$l = '';
 		while($cnt > 0) {	# Need some characters still
